Change log
---

### upcoming

- nothing currently planned

### 1.0.2

- _actually_ fixed broken setup.py

### 1.0.1

- tried to fix broken setup.py

### 1.0.0

- following internal review, and some fleshing out of the README, ready for release into the wild!

### 0.0.1

- initial version of `easy-geoparsing`
